<?php

/**
 * Cyber Fundraiser Metaboxes
 *
 * @author      Cybersourcepk
 * @category    Admin
 * @package     fundraiser/Admin
 * @version     0.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! class_exists( 'Cyber_Fundraiser_Metaboxes' ) ) :

/**
 * Cyber_Fundraiser_Metaboxes.
 */

class Cyber_Fundraiser_Metaboxes {

	public function __construct() {

		// add project meta boxes  
		 add_action('add_meta_boxes', array($this, 'cf_project_meta_boxes'));
		 
		 // save project meta boxes values
		 add_action('save_post', array($this, 'save'));

		
		 add_action('the_content', array($this, 'custom_message'));
	}

	/**
	* Adds the meta box container.
	*/
	public function cf_project_meta_boxes($post_type) {
	 	
	 	$post_types = array('projects');
	 
		 //limit meta box to certain post types
		 if (in_array($post_type, $post_types)) {
		 	
		 	add_meta_box('cs-meta',
		 	
		 		'Add Project Information',
		 	
		 		array($this, 'cf_meta_box_function'),
			
				$post_type,
		 	
		 		'normal',
		 		
		 		'high');
		}
	}

	public function cf_meta_box_function($post) {

		// Add an nonce field so we can check for it later.
		wp_nonce_field('cs_nonce_check', 'cs_nonce_check_value');
		 
		// Load Metaboxes HTML
		require('views/cyber_fundraiser_projects_metabox.php');
	
	}
		



	public function save($post_id) {

		/*
		* We need to verify this came from the our screen and with 
		* proper authorization,
		* because save_post can be triggered at other times.
		*/

		// Check if our nonce is set.
		if (!isset($_POST['cs_nonce_check_value']))
			return $post_id;

		$nonce = sanitize_text_field($_POST['cs_nonce_check_value']);

		// Verify that the nonce is valid.
		if (!wp_verify_nonce($nonce, 'cs_nonce_check'))
			return $post_id;

		// If this is an autosave, our form has not been submitted,
		//     so we don't want to do anything.
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;

		// Check the user's permissions.
		if ('page' == sanitize_text_field($_POST['post_type'])) {

			if (!current_user_can('edit_page', $post_id))
				return $post_id;

		} else {

			if (!current_user_can('edit_post', $post_id))
				return $post_id;
		}

		/* OK, its safe for us to save the data now. */

		// Sanitize the project goal input.
		$project_goal = sanitize_text_field($_POST['project_goal']);

		// Update the project goal meta field.
		update_post_meta($post_id, 'project_goal', $project_goal);

		// Sanitize the project_start_date input.
		$project_start_date = sanitize_text_field($_POST['project_start_date']);

		// Update the project_start_date meta field.
		update_post_meta($post_id, 'project_start_date', $project_start_date);

				// Sanitize the project_start_date input.
		  $project_end_date = sanitize_text_field($_POST['project_end_date']);

		  // Update the project_start_date meta field.
		  update_post_meta($post_id, 'project_end_date', $project_end_date);

		  // Sanitize the project_description input.
		  $project_short_description = sanitize_text_field($_POST['project_short_description']);


		  // Update the project_description meta field.
		  update_post_meta($post_id, 'project_short_description', $project_short_description);
		  
		  // Sanitize the receive_donations_after_goal_is_acheived input.
		 
		  $receive_donations_after_goal_is_acheived = sanitize_text_field($_POST['receive_donations_after_goal_is_acheived']);
		  // Update the receive_donations_after_goal_is_acheived meta field.
		  update_post_meta( $post_id, 'receive_donations_after_goal_is_acheived',$receive_donations_after_goal_is_acheived  );

		  // Sanitize the project_video_link input.
		  $project_video_link = sanitize_text_field($_POST['project_video_link']);

		  // Update the project_video_link meta field.
		  update_post_meta($post_id, 'project_video_link', $project_video_link);

		  // update slider shortcode
		  $project_slider = sanitize_text_field($_POST['project_slider']);
		  update_post_meta($post_id, 'project_slider', $project_slider);


		  // Sanitize the _cyber_fundraiser_layout input.
		  $_cyber_fundraiser_layout = sanitize_text_field($_POST['_cyber_fundraiser_layout']);

		  // Update the_cyber_fundraiser_layout meta field.
		  update_post_meta($post_id, '_cyber_fundraiser_layout', $_cyber_fundraiser_layout);
		  update_post_meta($post_id, 'status', 'active');
		  $projecDetails = cyber_frl_get_project_detail($projectID);
		  update_post_meta($post_id, 'total_raised_amount', $projecDetails['amount_raised']);
	}


	public function custom_message($content) {
		
		global $post;
		
		//retrieve the metadata values if they exist
		$data = get_post_meta($post -> ID, '_cs_custom_message', true);
		
		if (!empty($data)) {
			
			$custom_message = "<div style='background-color: #FFEBE8;border-color: #C00;padding: 2px;margin:2px;font-weight:bold;text-align:center'>";
			
			$custom_message .= $data;
			
			$custom_message .= "</div>";
			
			$content = $custom_message . $content;
		}

		return $content;
	}

		
}


endif;